# python-object-detector
Generic object detector interface for Python

https://semver.org/spec/v2.0.0.html
Given a version number MAJOR.MINOR.PATCH, increment the:

MAJOR version when you make incompatible API changes,
MINOR version when you add functionality in a backwards compatible manner, and
PATCH version when you make backwards compatible bug fixes.
Additional labels for pre-release and build metadata are available as extensions to the MAJOR.MINOR.PATCH format.

# Introduction
# Installation
# Usage
# History

# Development
```shell
black ./src/ ./tests/ .
```
```shell
mypy .
```
```shell
pflake8 .
```